<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'Android' => '',
    //'If you do not want to, or cannot use the official eduVPN apps, you can also manually obtain a VPN configuration and import it in your existing VPN application.' => '',
    //'Linux' => '',
    //'Manual Configuration' => '',
    //'On the "Account" page you can block access to the VPN in case you lose a device, or no longer use the VPN.' => '',
    'To use eduVPN, download the app for your device below!' => 'Para usar o eduVPN, descarregue abaixo, a aplicação para o seu dispositivo.',
    'Welcome to eduVPN!' => 'Bem-vindo ao eduVPN!',
    //'Windows' => '',
    //'iOS' => '',
    //'macOS' => '',
];
