:root {
  --nav-logo: url("../../img/eduVPN/logo.png");
  --bg-color-main-header: #e24301;
  --border-color: #e24301;
  --lead-text-color: #e24301;
  --img-linux: url("../../img/eduVPN/app/Linux.png");
  --img-windows: url("../../img/eduVPN/app/Windows.png");
  --img-macos: url("../../img/eduVPN/app/macOS.png");
  --img-android: url("../../img/eduVPN/app/Android.png");
  --img-ios: url("../../img/eduVPN/app/iOS.png");
}

/* Colors if the user prefer a dark mode */
@media (prefers-color-scheme: dark) {
  :root {
    --nav-logo: url("../../img/eduVPN/logo-dark.png");
    --img-macos: url("../../img/eduVPN/app/macOS-dark.png");
    --img-ios: url("../../img/eduVPN/app/iOS-dark.png");
  }
}

@font-face {
  font-family: "Open Sans";
  src: local("Open Sans"), url("../../fonts/eduVPN/OpenSans-Regular.woff2") format("woff2");
  font-weight: normal;
  font-style: normal;
}

@font-face {
  font-family: "Open Sans";
  src: local("Open Sans Bold"), url("../../fonts/eduVPN/OpenSans-Bold.woff2") format("woff2");
  font-weight: bold;
  font-style: normal;
}

@font-face {
  font-family: "Open Sans";
  src: local("Open Sans Italic"), url("../../fonts/eduVPN/OpenSans-Italic.woff2") format("woff2");
  font-weight: normal;
  font-style: italic;
}

@font-face {
  font-family: "Open Sans";
  src: local("Open Sans Bold Italic"), url("../../fonts/eduVPN/OpenSans-BoldItalic.woff2") format("woff2");
  font-weight: bold;
  font-style: italic;
}

body {
  font-family: "Open Sans", sans-serif;
}

nav {
  background-image: var(--nav-logo);
  background-size: 169px 50px;
  background-repeat: no-repeat;
  background-position: 50% 1em;
  min-height: calc(50px + 2em);
  padding: 0;
}

nav ul {
  padding: calc(50px + 1.5em) 0 0 0;
}

header.main h1 {
  background-color: var(--bg-color-main-header);
}

blockquote {
  border-left: 0.2em solid var(--border-color);
}

blockquote:lang(ar-MA) {
  border-right: 0.2em solid var(--border-color);
}

ul.apps {
  list-style: none;
  padding: 0;
  text-align: center;
}

ul.apps li {
  display: inline-block;
  padding: 2em;
}

ul.apps li a {
  display: block;
  background-repeat: no-repeat;
  background-size: 64px 64px;
  background-position: 50% 0;
  min-height: calc(64px + 2em);
  padding: calc(64px + 0.5em) 0 0 0;
  min-width: 64px;
}

ul.apps li a.Windows {
  background-image: var(--img-windows);
}

ul.apps li a.macOS {
  background-image: var(--img-macos);
}

ul.apps li a.Android {
  background-image: var(--img-android);
}

ul.apps li a.iOS {
  background-image: var(--img-ios);
}

ul.apps li a.Linux {
  background-image: var(--img-linux);
}

p.lead {
  color: var(--lead-text-color);
}

@media screen and (min-width: 800px) {
  nav {
    background-position: 2% 50%;
  }
  nav:lang(ar-MA) {
    background-position: 98% 50%;
  }
  nav ul {
    padding: 0 calc(169px + 2em);
  }
}
