<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    'Android' => 'Android',
    'If you do not want to, or cannot use the official eduVPN apps, you can also manually obtain a VPN configuration and import it in your existing VPN application.' => 'Falls du die offiziellen eduVPN-Apps nicht verwenden möchtest oder kannst, hast du alternativ die Möglichkeit, eine VPN-Konfiguration zu beziehen und in deine vorhandene VPN-Anwendung zu importieren.',
    'Linux' => 'Linux',
    'Manual Configuration' => 'Manuelle Konfiguration',
    'On the "Account" page you can block access to the VPN in case you lose a device, or no longer use the VPN.' => 'Auf der Seite "Benutzerkonto" kannst du deinen VPN-Zugang sperren, falls du dein Gerät verlierst, oder das VPN nicht mehr nutzt.',
    'To use eduVPN, download the app for your device below!' => 'Um eduVPN zu nutzen lade dir die App für dein Gerät herunter!',
    'Welcome to eduVPN!' => 'Willkommen bei eduVPN!',
    'Windows' => 'Windows',
    'iOS' => 'iOS',
    'macOS' => 'macOS',
];
